diff --git a/src/jamidht/conversation.cpp b/src/jamidht/conversation.cpp
index f8ec18291757a31390d13f81e7730c23556e7aa7..f08d695276a2f92f07f25c60369166c1e21920e8 100644
--- a/src/jamidht/conversation.cpp
+++ b/src/jamidht/conversation.cpp
@@ -1880,7 +1880,7 @@ Conversation::Impl::pull(const std::string& deviceId)
 
         bool commitFound = false;
         if (commitId != "") {
-            // If `commitId` is non-empty, then we were trying to pull a specific commit.
+            // If `commitId` is non-empty, then we were attempting to pull a specific commit.
             // We need to check if we actually got it; the fact that the fetch above was
             // successful doesn't guarantee that we did.
             for (const auto& commit : commits) {
@@ -1895,11 +1895,11 @@ Conversation::Impl::pull(const std::string& deviceId)
         if (!commitFound)
             JAMI_WARNING("Successfully fetched from device {} but didn't receive expected commit {}",
                          deviceId, commitId);
-        // WARNING: If its argument is `true`, this callback will try to send a message notification
+        // WARNING: If its argument is `true`, this callback will attempt to send a message notification
         //          for commit `commitId` to other members of the swarm. It's important that we only
         //          send these notifications if we actually have the commit. Otherwise, we can end up
         //          in a situation where the members of the swarm keep sending notifications to each
-        //          other for a commit that none of them have (note that we cannot rule this out, as
+        //          other for a commit that none of them have (note that we are unable to rule this out, as
         //          nothing prevents a malicious user from intentionally sending a notification with
         //          a fake commit ID).
         if (cb)
@@ -2414,7 +2414,7 @@ Conversation::bootstrap(std::function<void()> onBootstraped,
     if (!pimpl_ || !pimpl_->repository_ || !pimpl_->swarmManager_)
         return;
     // Here, we bootstrap the DRT with devices who already wrote in the conversation
-    // If this doesn't work, it will try to fallback with checkBootstrapMember
+    // If this doesn't work, it will attempt to fallback with checkBootstrapMember
     // If it works, the callback onConnectionChanged will be called with ok=true
     pimpl_->bootstrapCb_ = std::move(onBootstraped);
     std::vector<DeviceId> devices = knownDevices;
diff --git a/src/jamidht/conversationrepository.cpp b/src/jamidht/conversationrepository.cpp
index 5d767cd90fe60beaa520b15df8c223986f725d80..ac98a2c92449f5ad90ab5c57844d1356e018ae13 100644
--- a/src/jamidht/conversationrepository.cpp
+++ b/src/jamidht/conversationrepository.cpp
@@ -1949,7 +1949,7 @@ ConversationRepository::Impl::commit(const std::string& msg, bool verifyDevice)
 ConversationMode
 ConversationRepository::Impl::mode() const
 {
-    // If already retrieven, return it, else get it from first commit
+    // If already retrieved, return it, else get it from first commit
     if (mode_ != std::nullopt)
         return *mode_;
 
diff --git a/src/sip/sipcall.cpp b/src/sip/sipcall.cpp
index 1f250d21f7a7d55ddb48ca8d43700d92e7564f8a..68a7c29b1d27ede7645e00f438aace3f24762a44 100644
--- a/src/sip/sipcall.cpp
+++ b/src/sip/sipcall.cpp
@@ -915,7 +915,7 @@ SIPCall::answer(const std::vector<libjami::MediaMap>& mediaList)
 
     if (not inviteSession_->neg) {
         // We are answering to an INVITE that did not include a media offer (SDP).
-        // The SIP specification (RFCs 3261/6337) requires that if a UA wishes to
+        // The SIP specification (RFCs 3261/6337) requires that if a UA wants to
         // proceed with the call, it must provide a media offer (SDP) if the initial
         // INVITE did not offer one. In this case, the SDP offer will be included in
         // the SIP OK (200) answer. The peer UA will then include its SDP answer in
diff --git a/src/sip/sipvoiplink.cpp b/src/sip/sipvoiplink.cpp
index 09ffe2bad89ec64edf1ec9b33004515528e20138..4f6fbc26e72e722818c057c19336ea23eaa53cef 100644
--- a/src/sip/sipvoiplink.cpp
+++ b/src/sip/sipvoiplink.cpp
@@ -1525,7 +1525,7 @@ SIPVoIPLink::resolveSrvName(const std::string& name,
         token, [=, cb = std::move(cb)](pj_status_t s, const pjsip_server_addresses* r) {
             try {
                 if (s != PJ_SUCCESS || !r) {
-                    JAMI_WARN("Unable to resolve \"%s\" using pjsip_endpt_resolve, trying getaddrinfo.",
+                    JAMI_WARN("Unable to resolve \"%s\" using pjsip_endpt_resolve, attempting getaddrinfo.",
                               name.c_str());
                     dht::ThreadPool::io().run([=, cb = std::move(cb)]() {
                         auto ips = dhtnet::ip_utils::getAddrList(name.c_str());
diff --git a/test/unitTest/conversation/conversationMembersEvent.cpp b/test/unitTest/conversation/conversationMembersEvent.cpp
index 201a957ac7b4ee3703b49e318065fcbfce9f4265..a322d0ce38a4d129717378247f9b97cf2fc9c1bb 100644
--- a/test/unitTest/conversation/conversationMembersEvent.cpp
+++ b/test/unitTest/conversation/conversationMembersEvent.cpp
@@ -91,7 +91,7 @@ public:
     void testMemberCannotBanOther();
     void testMemberCannotUnBanOther();
     void testCheckAdminFakeAVoteIsDetected();
-    void testAdminCannotKickTheirself();
+    void testAdminCannotKickThemselves();
     void testCommitUnauthorizedUser();
     void testMemberJoinsNoBadFile();
     void testMemberAddedNoCertificate();
@@ -145,7 +145,7 @@ private:
     CPPUNIT_TEST(testMemberCannotBanOther);
     CPPUNIT_TEST(testMemberCannotUnBanOther);
     CPPUNIT_TEST(testCheckAdminFakeAVoteIsDetected);
-    CPPUNIT_TEST(testAdminCannotKickTheirself);
+    CPPUNIT_TEST(testAdminCannotKickThemselves);
     CPPUNIT_TEST(testCommitUnauthorizedUser);
     CPPUNIT_TEST(testMemberJoinsNoBadFile);
     CPPUNIT_TEST(testMemberAddedNoCertificate);
@@ -1097,7 +1097,7 @@ ConversationMembersEventTest::testCheckAdminFakeAVoteIsDetected()
 }
 
 void
-ConversationMembersEventTest::testAdminCannotKickTheirself()
+ConversationMembersEventTest::testAdminCannotKickThemselves()
 {
     connectSignals();
diff --git a/src/jamidht/jamiaccount.cpp b/src/jamidht/jamiaccount.cpp
index 4934ba8ef5150640782bec436bbcfea7d5435b8c..61590eb5f6245a8de7624adbc124824463b35b49 100644
--- a/src/jamidht/jamiaccount.cpp
+++ b/src/jamidht/jamiaccount.cpp
@@ -112,7 +112,7 @@ static constexpr const char MIME_TYPE_INVITE_JSON[] {"application/invite+json"};
 static constexpr const char DEVICE_ID_PATH[] {"ring_device"};
 static constexpr auto TREATED_PATH = "treatedImMessages"sv;
 
-// Used to pass infos to a pjsip callback (pjsip_endpt_send_request)
+// Used to pass info to a pjsip callback (pjsip_endpt_send_request)
 struct TextMessageCtx
 {
     std::weak_ptr<JamiAccount> acc;
@@ -459,7 +459,7 @@ JamiAccount::newSwarmOutgoingCallHelper(const Uri& uri,
                 } catch (const VoipLinkException&) {
                     // In this case, the main scenario is that SIPStartCall failed because
                     // the ICE is dead and the TLS session didn't send any packet on that dead
-                    // link (connectivity change, killed by the os, etc)
+                    // link (connectivity change, killed by the operating system, etc)
                     // Here, we don't need to do anything, the TLS will fail and will delete
                     // the cached transport
                     continue;
@@ -741,8 +741,8 @@ JamiAccount::startOutgoingCall(const std::shared_ptr<SIPCall>& call, const std::
         [wCall](bool ok) {
             if (not ok) {
                 if (auto call = wCall.lock()) {
-                    JAMI_WARNING("[call:{}] no devices found", call->getCallId());
-                    // Note: if a p2p connection exists, the call will be at least in CONNECTING
+                    JAMI_WARNING("[call:{}] No devices found", call->getCallId());
+                    // Note: if a P2P connection exists, the call will be at least in CONNECTING
                     if (call->getConnectionState() == Call::ConnectionState::TRYING)
                         call->onFailure(static_cast<int>(std::errc::no_such_device_or_address));
                 }
@@ -757,7 +757,7 @@ JamiAccount::onConnectedOutgoingCall(const std::shared_ptr<SIPCall>& call,
 {
     if (!call)
         return;
-    JAMI_LOG("[call:{}] outgoing call connected to {}", call->getCallId(), to_id);
+    JAMI_LOG("[call:{}] Outgoing call connected to {}", call->getCallId(), to_id);
 
     const auto localAddress = dhtnet::ip_utils::getInterfaceAddr(getLocalInterface(),
                                                                  target.getFamily());
@@ -784,7 +784,7 @@ JamiAccount::onConnectedOutgoingCall(const std::shared_ptr<SIPCall>& call,
     auto mediaAttrList = call->getMediaAttributeList();
 
     if (mediaAttrList.empty()) {
-        JAMI_ERROR("[call:{}] no media. Abort!", call->getCallId());
+        JAMI_ERROR("[call:{}] No media. Abort!", call->getCallId());
         return;
     }
 
@@ -835,7 +835,7 @@ JamiAccount::SIPStartCall(SIPCall& call, const dhtnet::IpAddr& target)
     auto contact = call.getContactHeader();
     auto pjContact = sip_utils::CONST_PJ_STR(contact);
 
-    JAMI_LOG("[call:{}] contact header: {} / {} -> {} / {}",
+    JAMI_LOG("[call:{}] Contact header: {} / {} -> {} / {}",
              call.getCallId(),
              contact,
              from,
@@ -1116,7 +1116,7 @@ JamiAccount::loadAccount(const std::string& archive_password_scheme,
     if (registrationState_ == RegistrationState::INITIALIZING)
         return;
 
-    JAMI_DEBUG("[Account {:s}] loading account", getAccountID());
+    JAMI_DEBUG("[Account {:s}] Loading account", getAccountID());
     AccountManager::OnChangeCallback callbacks {
         [this](const std::string& uri, bool confirmed) {
             if (!id_.first)
@@ -1253,9 +1253,9 @@ JamiAccount::loadAccount(const std::string& archive_password_scheme,
             // normal loading path
             id_ = std::move(id);
             config_->username = info->accountId;
-            JAMI_WARNING("[Account {:s}] loaded account identity", getAccountID());
+            JAMI_WARNING("[Account {:s}] Loaded account identity", getAccountID());
             if (info->identity.first->getPublicKey().getLongId() != oldIdentity) {
-                JAMI_WARNING("[Account {:s}] identity changed", getAccountID());
+                JAMI_WARNING("[Account {:s}] Identity changed", getAccountID());
                 {
                     std::lock_guard lk(moduleMtx_);
                     convModule_.reset();
@@ -1405,7 +1405,7 @@ JamiAccount::loadAccount(const std::string& archive_password_scheme,
                 callbacks);
         }
     } catch (const std::exception& e) {
-        JAMI_WARNING("[Account {}] error loading account: {}", getAccountID(), e.what());
+        JAMI_WARNING("[Account {}] Error loading account: {}", getAccountID(), e.what());
         accountManager_.reset();
         setRegistrationState(RegistrationState::ERROR_GENERIC);
     }
@@ -1558,7 +1558,7 @@ JamiAccount::registerAsyncOps()
                 auto& dhtMap = accPtr->dhtUpnpMapping_;
                 const auto& accId = accPtr->getAccountID();
 
-                JAMI_LOG("[Account {:s}] DHT UPNP mapping changed to {:s}",
+                JAMI_LOG("[Account {:s}] DHT UPnP mapping changed to {:s}",
                          accId,
                          mapRes->toString(true));
 
@@ -1634,7 +1634,7 @@ JamiAccount::doRegister()
         return;
     }
 
-    JAMI_LOG("[Account {:s}] Starting account..", getAccountID());
+    JAMI_LOG("[Account {:s}] Starting account…", getAccountID());
 
     // invalid state transitions:
     // INITIALIZING: generating/loading certificates, unable to register
@@ -1812,7 +1812,7 @@ JamiAccount::onTrackedBuddyOffline(const dht::InfoHash& contactId)
     auto& state = presenceState_[id];
     if (state > PresenceState::DISCONNECTED) {
         if (state == PresenceState::CONNECTED) {
-            JAMI_WARNING("Buddy {} is not present on the DHT, but p2p connected", id);
+            JAMI_WARNING("Buddy {} is not present on the DHT, but P2P connected", id);
         }
         state = PresenceState::DISCONNECTED;
         emitSignal<libjami::PresenceSignal::NewBuddyNotification>(getAccountID(),
@@ -1827,7 +1827,7 @@ void
 JamiAccount::doRegister_()
 {
     if (registrationState_ != RegistrationState::TRYING) {
-        JAMI_ERROR("[Account {}] already registered", getAccountID());
+        JAMI_ERROR("[Account {}] Already registered", getAccountID());
         return;
     }
 
@@ -1885,7 +1885,7 @@ JamiAccount::doRegister_()
             config.proxy_server = proxyServerCached_;
 
         if (not config.proxy_server.empty()) {
-            JAMI_LOG("[Account {}] using proxy server {}", getAccountID(), config.proxy_server);
+            JAMI_LOG("[Account {}] Using proxy server {}", getAccountID(), config.proxy_server);
             if (not config.push_token.empty()) {
                 JAMI_LOG(
                     "[Account {}] using push notifications with platform: {}, topic: {}, token: {}",
@@ -1900,7 +1900,7 @@ JamiAccount::doRegister_()
         if (conf.accountPeerDiscovery or conf.accountPublish) {
             peerDiscovery_ = std::make_shared<dht::PeerDiscovery>();
             if (conf.accountPeerDiscovery) {
-                JAMI_LOG("[Account {}] starting Jami account discovery…", getAccountID());
+                JAMI_LOG("[Account {}] Starting Jami account discovery…", getAccountID());
                 startAccountDiscovery();
             }
             if (conf.accountPublish)
@@ -2061,7 +2061,7 @@ JamiAccount::doRegister_()
                     auto remoteDevice = name.substr(6, sep - 6);
 
                     if (channel->isInitiator()) {
-                        // Check if wanted remote it's our side (git://remoteDevice/conversationId)
+                        // Check if wanted remote is our side (git://remoteDevice/conversationId)
                         return;
                     }
 
@@ -2366,7 +2366,7 @@ JamiAccount::doUnregister(std::function<void(bool)> released_cb)
         peerDiscovery_->stopDiscovery(PEER_DISCOVERY_JAMI_SERVICE);
     }
 
-    JAMI_WARN("[Account %s] unregistering account %p", getAccountID().c_str(), this);
+    JAMI_WARN("[Account %s] Unregistering account %p", getAccountID().c_str(), this);
     dht_->shutdown(
         [&] {
             JAMI_WARN("[Account %s] dht shutdown complete", getAccountID().c_str());
@@ -2381,13 +2381,13 @@ JamiAccount::doUnregister(std::function<void(bool)> released_cb)
         pendingCalls_.clear();
     }
 
-    // Stop all current p2p connections if account is disabled
+    // Stop all current P2P connections if account is disabled
     // Else, we let the system managing if the co is down or not
     // NOTE: this is used for changing account's config.
     if (not isEnabled())
         shutdownConnections();
 
     // Release current upnp mapping if any.
     if (upnpCtrl_ and dhtUpnpMapping_.isValid()) {
         upnpCtrl_->releaseMapping(dhtUpnpMapping_);
     }
@@ -2416,15 +2416,15 @@ JamiAccount::setRegistrationState(RegistrationState state,
 {
     if (registrationState_ != state) {
         if (state == RegistrationState::REGISTERED) {
-            JAMI_WARNING("[Account {}] connected", getAccountID());
+            JAMI_WARNING("[Account {}] Connected", getAccountID());
             turnCache_->refresh();
             if (connectionManager_)
                 connectionManager_->storeActiveIpAddress();
         } else if (state == RegistrationState::TRYING) {
-            JAMI_WARNING("[Account {}] connecting…", getAccountID());
+            JAMI_WARNING("[Account {}] Connecting…", getAccountID());
         } else {
             deviceAnnounced_ = false;
-            JAMI_WARNING("[Account {}] disconnected", getAccountID());
+            JAMI_WARNING("[Account {}] Disconnected", getAccountID());
         }
     }
     // Update registrationState_ & emit signals
@@ -2600,7 +2600,7 @@ JamiAccount::loadCachedUrl(const std::string& url,
                         } else {
                             try {
                                 if (std::filesystem::exists(cachePath)) {
-                                    JAMI_WARNING("Failed to download url, using cached data");
+                                    JAMI_WARNING("Failed to download URL, using cached data");
                                     std::string data;
                                     {
                                         std::lock_guard lk(
@@ -2381,13 +2381,13 @@ JamiAccount::doUnregister(std::function<void(bool)> released_cb)
         shutdownConnections();
 
-    // Release current upnp mapping if any.
+    // Release current UPnP mapping if any.
     if (upnpCtrl_ and dhtUpnpMapping_.isValid()) {
         upnpCtrl_->releaseMapping(dhtUpnpMapping_);
diff --git a/src/manager.cpp b/src/manager.cpp
index 2e755fa0fff3407a3e5c0d334a6bf9f5bd29b822..9415dfe1be4eca78abfbdbd5773670af51f936d4 100644
--- a/src/manager.cpp
+++ b/src/manager.cpp
@@ -657,7 +657,7 @@ Manager::ManagerPimpl::sendTextMessageToConference(const Conference& conf,
         try {
             auto call = base_.getCallFromCallID(callId);
             if (not call)
-                throw std::runtime_error("no associated call");
+                throw std::runtime_error("No associated call");
             call->sendTextMessage(messages, from);
         } catch (const std::exception& e) {
             JAMI_ERR("Failed to send message to conference participant %s: %s",
@@ -684,7 +684,7 @@ Manager::ManagerPimpl::bindCallToConference(Call& call, Conference& conf)
     if (call.isConferenceParticipant())
         base_.detachParticipant(callId);
 
-    JAMI_DEBUG("[call:{}] bind to conference {} (callState={})", callId, confId, state);
+    JAMI_DEBUG("[call:{}] Bind to conference {} (callState={})", callId, confId, state);
 
     auto medias = call.getAudioStreams();
     for (const auto& media : medias) {
@@ -702,7 +702,7 @@ Manager::ManagerPimpl::bindCallToConference(Call& call, Conference& conf)
     } else if (state == "INACTIVE") {
         base_.answerCall(call);
     } else
-        JAMI_WARNING("[call:{}] call state {} not recognized for conference", callId, state);
+        JAMI_WARNING("[call:{}] Call state {} unrecognized for conference", callId, state);
 }
 
 //==============================================================================
@@ -714,7 +714,7 @@ Manager::instance()
     static Manager instance;
 
     // This will give a warning that can be ignored the first time instance()
-    // is called...subsequent warnings are more serious
+    // is called… subsequent warnings are more serious
     if (not Manager::initialized)
         JAMI_DBG("Not initialized");
 
@@ -887,8 +887,8 @@ Manager::finish() noexcept
         // Forbid call creation
         callFactory.forbid();
 
-        // Hangup all remaining active calls
-        JAMI_DBG("Hangup %zu remaining call(s)", callFactory.callCount());
+        // End all remaining active calls
+        JAMI_DBG("End %zu remaining call(s)", callFactory.callCount());
         for (const auto& call : callFactory.getAllCalls())
             hangupCall(call->getAccountId(), call->getCallId());
         callFactory.clear();
@@ -1178,7 +1178,7 @@ Manager::hangupCall(const std::string& accountId, const std::string& callId)
     /* We often get here when the call was hungup before being created */
     auto call = account->getCall(callId);
     if (not call) {
-        JAMI_WARN("Unable to hang up non-existant call %s", callId.c_str());
+        JAMI_WARN("Unable to hang up nonexistent call %s", callId.c_str());
         return false;
     }
 
@@ -1269,7 +1269,7 @@ Manager::offHoldCall(const std::string&, const std::string& callId)
     try {
         result = call->offhold([=](bool ok) {
             if (!ok) {
-                JAMI_ERR("Off hold failed for call %s", callId.c_str());
+                JAMI_ERR("offHold failed for call %s", callId.c_str());
                 return;
             }
 
@@ -1437,7 +1437,7 @@ Manager::ManagerPimpl::addMainParticipant(Conference& conf)
 bool
 Manager::ManagerPimpl::hangupConference(Conference& conference)
 {
-    JAMI_DEBUG("Hangup conference {}", conference.getConfId());
+    JAMI_DEBUG("hangupConference {}", conference.getConfId());
     CallIdSet subcalls(conference.getSubCalls());
     conference.detachHost();
     if (subcalls.empty()) {
@@ -1834,7 +1834,7 @@ Manager::playDtmf(char code)
     stopTone();
 
     if (not voipPreferences.getPlayDtmf()) {
-        JAMI_DBG("Do not have to play a tone...");
+        JAMI_DBG("Do not have to play a tone…");
         return;
     }
 
@@ -1842,7 +1842,7 @@ Manager::playDtmf(char code)
     int pulselen = voipPreferences.getPulseLength();
 
     if (pulselen == 0) {
-        JAMI_DBG("Pulse length is not set...");
+        JAMI_DBG("Pulse length is not set…");
         return;
     }
 
@@ -1850,13 +1850,13 @@ Manager::playDtmf(char code)
 
     // fast return, no sound, so no dtmf
     if (not pimpl_->audiodriver_ or not pimpl_->dtmfKey_) {
-        JAMI_DBG("No audio layer...");
+        JAMI_DBG("No audio layer…");
         return;
     }
 
     std::shared_ptr<AudioDeviceGuard> audioGuard = startAudioStream(AudioDeviceType::PLAYBACK);
     if (not pimpl_->audiodriver_->waitForStart(std::chrono::seconds(1))) {
-        JAMI_ERR("Failed to start audio layer...");
+        JAMI_ERR("Failed to start audio layer…");
         return;
     }
 
@@ -1874,7 +1874,7 @@ Manager::playDtmf(char code)
     // copy the sound
     if (pimpl_->dtmfKey_->generateDTMF(pimpl_->dtmfBuf_->pointer())) {
         // Put buffer to urgentRingBuffer
-        // put the size in bytes...
+        // put the size in bytes…
         // so size * 1 channel (mono) * sizeof (bytes for the data)
         // audiolayer->flushUrgent();
 
@@ -1977,7 +1977,7 @@ Manager::sendCallTextMessage(const std::string& accountId,
                 JAMI_DBG("Call is participant in a conference, send instant message to everyone");
                 pimpl_->sendTextMessageToConference(*conf, messages, from);
             } else {
-                JAMI_ERR("no conference associated to call ID %s", callID.c_str());
+                JAMI_ERR("No conference associated to call ID %s", callID.c_str());
             }
         } else {
             try {
@@ -1989,7 +1989,7 @@ Manager::sendCallTextMessage(const std::string& accountId,
             }
         }
     } else {
-        JAMI_ERR("Failed to send message to %s: inexistent call ID", callID.c_str());
+        JAMI_ERR("Failed to send message to %s: nonexistent call ID", callID.c_str());
     }
 }
 
@@ -2161,7 +2161,7 @@ Manager::playRingtone(const std::string& accountID)
         std::lock_guard lock(pimpl_->audioLayerMutex_);
 
         if (not pimpl_->audiodriver_) {
-            JAMI_ERR("no audio layer in ringtone");
+            JAMI_ERR("No audio layer in ringtone");
             return;
         }
         // start audio if not started AND flush all buffers (main and urgent)
@@ -2216,7 +2216,7 @@ Manager::setAudioDevice(int index, AudioDeviceType type)
         return;
     }
     if (pimpl_->getCurrentDeviceIndex(type) == index) {
-        JAMI_WARN("Audio device already selected ; doing nothing.");
+        JAMI_WARN("Audio device already selected, doing nothing.");
         return;
     }
 
@@ -2332,10 +2332,10 @@ Manager::toggleRecordingCall(const std::string& accountId, const std::string& id
     if (auto account = getAccount(accountId)) {
         std::shared_ptr<Recordable> rec;
         if (auto conf = account->getConference(id)) {
-            JAMI_DBG("toggle recording for conference %s", id.c_str());
+            JAMI_DBG("Toggle recording for conference %s", id.c_str());
             rec = conf;
         } else if (auto call = account->getCall(id)) {
-            JAMI_DBG("toggle recording for call %s", id.c_str());
+            JAMI_DBG("Toggle recording for call %s", id.c_str());
             rec = call;
         } else {
             JAMI_ERR("Unable to find recordable instance %s", id.c_str());
@@ -2423,7 +2423,7 @@ Manager::setAudioManager(const std::string& api)
             return false;
 
         if (api == audioPreference.getAudioApi()) {
-            JAMI_DBG("Audio manager chosen already in use. No changes made. ");
+            JAMI_DBG("Audio manager chosen already in use. No changes made.");
             return true;
         }
     }
@@ -2714,7 +2714,7 @@ Manager::getAccountDetails(const std::string& accountID) const
     if (account) {
         return account->getAccountDetails();
     } else {
-        JAMI_ERR("Unable to get account details on a non-existing accountID %s", accountID.c_str());
+        JAMI_ERR("Unable to get account details on a nonexistent accountID %s", accountID.c_str());
         // return an empty map since unable to throw an exception to D-Bus
         return {};
     }
@@ -2728,7 +2728,7 @@ Manager::getVolatileAccountDetails(const std::string& accountID) const
     if (account) {
         return account->getVolatileAccountDetails();
     } else {
-        JAMI_ERR("Unable to get volatile account details on a non-existing accountID %s",
+        JAMI_ERR("Unable to get volatile account details on a nonexistent accountID %s",
                  accountID.c_str());
         return {};
     }
@@ -3269,7 +3269,7 @@ Manager::setDefaultModerator(const std::string& accountID, const std::string& pe
 {
     auto acc = getAccount(accountID);
     if (!acc) {
-        JAMI_ERR("Fail to change default moderator, account %s not found", accountID.c_str());
+        JAMI_ERR("Failed to change default moderator, account %s not found", accountID.c_str());
         return;
     }
 
@@ -3285,7 +3285,7 @@ Manager::getDefaultModerators(const std::string& accountID)
 {
     auto acc = getAccount(accountID);
     if (!acc) {
-        JAMI_ERR("Fail to get default moderators, account %s not found", accountID.c_str());
+        JAMI_ERR("Failed to get default moderators, account %s not found", accountID.c_str());
         return {};
     }
 
@@ -3306,7 +3306,7 @@ Manager::isLocalModeratorsEnabled(const std::string& accountID)
 {
     auto acc = getAccount(accountID);
     if (!acc) {
-        JAMI_ERR("Fail to get local moderators, account %s not found", accountID.c_str());
+        JAMI_ERR("Failed to get local moderators, account %s not found", accountID.c_str());
         return true; // Default value
     }
     return acc->isLocalModeratorsEnabled();
@@ -3324,7 +3324,7 @@ Manager::isAllModerators(const std::string& accountID)
 {
     auto acc = getAccount(accountID);
     if (!acc) {
-        JAMI_ERR("Fail to get all moderators, account %s not found", accountID.c_str());
+        JAMI_ERR("Failed to get all moderators, account %s not found", accountID.c_str());
         return true; // Default value
     }
     return acc->isAllModerators();